/*
    Copyright (C) 1995-1998 AROS - The Amiga Research OS
    $Id: freedeviceproc.c,v 1.1.1.1 2005/03/15 15:54:40 laire Exp $

    Desc: FreeDeviceProc() - Clean up after calls to GetDeviceProc()
    Lang: english
*/
#include "dos_intern.h"
#include <proto/exec.h>

/*****************************************************************************

    NAME */
#include <dos/dosextens.h>
#include <proto/dos.h>

	AROS_LH1(void, FreeDeviceProc,

/*  SYNOPSIS */
	AROS_LHA(struct DevProc *, dp, D1),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 108, Dos)

/*  FUNCTION
	FreeDeviceProc() will clean up after a call to GetDeviceProc().

    INPUTS
	dp		- DevProc structure as returned by GetDeviceProc().

    RESULT
	Some memory and other resources returned to the system.

    NOTES

    EXAMPLE

    BUGS

    SEE ALSO
	GetDeviceProc()

    INTERNALS

    HISTORY
	27-11-96    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    DEBUG_DEVICEPROC(dprintf("FreeDeviceProc: devproc = $%lx\n", (ULONG) dp));

    FAILFORTASKNP(return;)

    if (dp)
    {
	DEBUG_DEVICEPROC(dprintf("FreeDeviceProc: flags = $%lx\n", dp->dvp_Flags));
#if USE_FSCONTEXT
	if (dp->dvp_Flags & DVPF_FSCONTEXT)
	{
	    DEBUG_DEVICEPROC(dprintf("FreeDeviceProc: ReleaseFSContext($%lx)\n", dp->dvp_FSContext));
	    ReleaseFSContext(DOSBase,dp->dvp_FSContext);
	}
#endif
	if (dp->dvp_Flags & DVPF_UNLOCK)
	{
	    DEBUG_DEVICEPROC(dprintf("FreeDeviceProc: free lock = $%lx\n", dp->dvp_Lock));
	    UnLock(dp->dvp_Lock);
	}
	dosFreeMem(dp, sizeof(struct DevProc));
    }

    AROS_LIBFUNC_EXIT
} /* FreeDeviceProc */
